@@ -29,13 +29,18 @@
 
 #include "big_banner_penguin.h"
 #include "big_banner_bsd.h"
-#include "big_banner_sun.h"
 
 #include "image.h"
 
 #include "ctkdevice.h"
 #include "ctkhelp.h"
-#include "ctkutils.h"
+
+static void add_table_row(GtkWidget *table,
+                          const gint row,
+                          const gint value_alignment,
+                          const gchar *name,
+                          const gchar *value);
+
 #define N_GDK_PIXBUFS 45
 
 
@@ -143,8 +148,7 @@ GtkWidget* ctk_device_new(
     os = NULL;
     if (ret == NvCtrlSuccess) {
         if (os_val == NV_CTRL_OPERATING_SYSTEM_LINUX) os = "Linux";
-        else if (os_val == NV_CTRL_OPERATING_SYSTEM_FREEBSD) os = "FreeBSD";
-        else if (os_val == NV_CTRL_OPERATING_SYSTEM_SUNOS) os = "SunOS";
+        if (os_val == NV_CTRL_OPERATING_SYSTEM_FREEBSD) os = "FreeBSD";
     }
     if (!os) os = __unknown;
 
@@ -194,12 +198,8 @@ GtkWidget* ctk_device_new(
 
     if (os_val == NV_CTRL_OPERATING_SYSTEM_LINUX) {
         img = &big_banner_penguin_image;
-    } else if (os_val == NV_CTRL_OPERATING_SYSTEM_FREEBSD) {
-        img = &big_banner_bsd_image;
-    } else if (os_val == NV_CTRL_OPERATING_SYSTEM_SUNOS) {
-        img = &big_banner_sun_image;
     } else {
-        img = &big_banner_penguin_image; /* Should never get here */
+        img = &big_banner_bsd_image;
     }
 
     image_buffer = decompress_image_data(img);
@@ -256,6 +256,26 @@ GtkWidget* ctk_device_new(
     return GTK_WIDGET(object);
 }
 
+
+static void add_table_row(GtkWidget *table,
+                          const gint row,
+                          const gint value_alignment,
+                          const gchar *name,
+                          const gchar *value)
+{
+    GtkWidget *label;
+
+    label = gtk_label_new(name);
+    gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+    gtk_table_attach(GTK_TABLE(table), label, 0, 1, row, row + 1,
+                     GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+
+    label = gtk_label_new(value);
+    gtk_misc_set_alignment(GTK_MISC(label), value_alignment, 0.5);
+    gtk_table_attach(GTK_TABLE(table), label, 1, 2, row, row + 1,
+                     GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+}
+    
     
 GtkTextBuffer *ctk_device_create_help(GtkTextTagTable *table,
                                       const gchar *screen_name)
