@@ -30,10 +30,6 @@
  */
 
 #include <gtk/gtk.h>
-
-#include <X11/Xlib.h> /* Xrandr */
-#include <X11/extensions/Xrandr.h> /* Xrandr */
-
 #include "ctkevent.h"
 #include "NVCtrlLib.h"
 
@@ -49,13 +45,11 @@ typedef struct {
     Display *dpy;
     GPollFD event_poll_fd;
     int event_base;
-    int randr_event_base;
     CtkEvent *ctk_event;
 } CtkEventSource;
 
 
 static guint signals[NV_CTRL_LAST_ATTRIBUTE + 1];
-static guint signal_RRScreenChangeNotify;
 
 
 
@@ -82,7 +76,7 @@ GType ctk_event_get_type(void)
 
     return ctk_event_type;
     
-} /* ctk_event_get_type() */
+} /* ctk_window_get_type() */
 
 
 static void ctk_event_class_init(CtkEventClass *ctk_event_class)
@@ -187,13 +181,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_GVO_VIDEO_FORMAT_REFRESH_RATE);
     MAKE_SIGNAL(NV_CTRL_GVO_X_SCREEN_PAN_X);
     MAKE_SIGNAL(NV_CTRL_GVO_X_SCREEN_PAN_Y);
-    MAKE_SIGNAL(NV_CTRL_GPU_OVERCLOCKING_STATE);
-    MAKE_SIGNAL(NV_CTRL_GPU_2D_CLOCK_FREQS);
-    MAKE_SIGNAL(NV_CTRL_GPU_3D_CLOCK_FREQS);
-    MAKE_SIGNAL(NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS);
-    MAKE_SIGNAL(NV_CTRL_GPU_OPTIMAL_CLOCK_FREQS_DETECTION_STATE);
-    MAKE_SIGNAL(NV_CTRL_USE_HOUSE_SYNC);
-
+    
 #undef MAKE_SIGNAL
     
     /*
@@ -203,20 +191,10 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
      * knows about.
      */
 
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_USE_HOUSE_SYNC
+#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_GVO_X_SCREEN_PAN_Y
 #warning "There are attributes that do not emit signals!"
 #endif
 
-
-    /* Make XRandR signal */
-    signal_RRScreenChangeNotify =
-        g_signal_new("CTK_EVENT_RRScreenChangeNotify",
-                     G_OBJECT_CLASS_TYPE(ctk_event_class),
-                     G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-                     g_cclosure_marshal_VOID__POINTER,
-                     G_TYPE_NONE, 1, G_TYPE_POINTER);
-
-
 } /* ctk_event_class_init */
 
 
@@ -256,7 +234,6 @@ GtkObject *ctk_event_new (NvCtrlAttributeHandle *handle)
     event_source->event_poll_fd.fd = ConnectionNumber(dpy);
     event_source->event_poll_fd.events = G_IO_IN;
     event_source->event_base = NvCtrlGetEventBase(handle);
-    event_source->randr_event_base = NvCtrlGetXrandrEventBase(handle);
     event_source->ctk_event = ctk_event;
 
     /* add the input source to the glib main loop */
@@ -265,8 +242,7 @@ GtkObject *ctk_event_new (NvCtrlAttributeHandle *handle)
     g_source_attach(source, NULL);
     
     return GTK_OBJECT(ctk_event);
-
-} /* ctk_event_new() */
+}
 
 
 static gboolean ctk_event_prepare(GSource *source, gint *timeout)
@@ -285,12 +261,11 @@ static gboolean ctk_event_check(GSource *source)
 {
     CtkEventSource *event_source = (CtkEventSource *) source;
 
-    /*
-     * XXX We could check for (event_source->event_poll_fd.revents & G_IO_IN),
-     * but doing so caused some events to be missed as they came in with only
-     * the G_IO_OUT flag set which is odd.
-     */
-    return XPending(event_source->dpy);
+    if (event_source->event_poll_fd.revents & G_IO_IN) {
+        return XPending(event_source->dpy);
+    }
+    
+    return FALSE;
 }
 
 static gboolean ctk_event_dispatch(GSource *source,
@@ -337,16 +312,6 @@ static gboolean ctk_event_dispatch(GSource *source,
                           0, &event_struct);
         }
     }
-
-    /*
-     * Also handle XRandR events.
-     */
-    if (event.type ==
-        (event_source->randr_event_base + RRScreenChangeNotify)) {
-        g_signal_emit(event_source->ctk_event, signal_RRScreenChangeNotify,
-                      0, &event);
-    }
     
     return TRUE;
-
-} /* ctk_event_dispatch() */
+}
