@@ -42,13 +42,10 @@
 #include "ctkdevice.h"
 #include "ctkcolorcorrection.h"
 #include "ctkxvideo.h"
-#include "ctkrandr.h"
 #include "ctkcursorshadow.h"
 #include "ctkopengl.h"
-#include "ctkglx.h"
 #include "ctkmultisample.h"
 #include "ctkthermal.h"
-#include "ctkclocks.h"
 
 #include "ctkdisplaydevice.h"
 #include "ctkdisplaydevice-crt.h"
@@ -66,25 +63,19 @@ enum {
     CTK_WINDOW_WIDGET_COLUMN,
     CTK_WINDOW_HELP_COLUMN,
     CTK_WINDOW_CONFIG_FILE_ATTRIBUTES_FUNC_COLUMN,
-    CTK_WINDOW_SELECT_WIDGET_FUNC_COLUMN,
-    CTK_WINDOW_UNSELECT_WIDGET_FUNC_COLUMN,
     CTK_WINDOW_NUM_COLUMNS
 };
 
 
 typedef void (*config_file_attributes_func_t)(GtkWidget *, ParsedAttribute *);
-typedef void (*select_widget_func_t)(GtkWidget *);
-typedef void (*unselect_widget_func_t)(GtkWidget *);
 
 static void ctk_window_class_init(CtkWindowClass *);
 
 static void ctk_window_real_destroy(GtkObject *);
 
 static void add_page(GtkWidget *, GtkTextBuffer *, CtkWindow *,
-                     GtkTreeIter *, GtkTreeIter *, const gchar *,
-                     config_file_attributes_func_t func,
-                     select_widget_func_t load_func,
-                     unselect_widget_func_t unload_func);
+                     GtkTreeIter *, const gchar *,
+                     config_file_attributes_func_t func);
 
 static GtkWidget *create_quit_dialog(CtkWindow *ctk_window);
 
@@ -227,17 +218,12 @@ static void tree_selection_changed(GtkTreeSelection *selection,
     GtkWidget *widget;
     GtkTextBuffer *help;
 
-    select_widget_func_t select_func;
-    unselect_widget_func_t unselect_func;
-
     if (!gtk_tree_selection_get_selected(selection, &model, &iter))
         return;
 
     gtk_tree_model_get(model, &iter, CTK_WINDOW_LABEL_COLUMN, &str, -1);
     gtk_tree_model_get(model, &iter, CTK_WINDOW_WIDGET_COLUMN, &widget, -1);
     gtk_tree_model_get(model, &iter, CTK_WINDOW_HELP_COLUMN, &help, -1);
-    gtk_tree_model_get(model, &iter, CTK_WINDOW_SELECT_WIDGET_FUNC_COLUMN,
-                       &select_func, -1);
 
     /*
      * remove the existing widget from the page viewer, if anything is
@@ -250,37 +236,15 @@ static void tree_selection_changed(GtkTreeSelection *selection,
         ctk_window->page = NULL;
     }
 
-    /* Call the unselect func for the existing widget, if any */
-
-    if ( ctk_window->widget ) {
-        gtk_tree_model_get(model, &(ctk_window->iter),
-                           CTK_WINDOW_UNSELECT_WIDGET_FUNC_COLUMN,
-                           &unselect_func, -1);
-        if ( unselect_func ) {
-            (*unselect_func)(ctk_window->widget);
-        }
-    }
-
-    /* Pack the new widget */
-
     if (widget) {
         ctk_window->page = widget;
         gtk_box_pack_start(GTK_BOX(ctk_window->page_viewer), widget,
                            TRUE, TRUE, 2);
     }
 
-    /* Call the select func for the new widget */
-
-    if (select_func) (*select_func)(widget);
-
     /* update the help page */
 
     ctk_help_set_page(CTK_HELP(ctk_window->ctk_help), help);
-
-    /* Keep track of the selected widget */
-
-    ctk_window->iter = iter;
-    ctk_window->widget = widget;
     
 } /* tree_selection_changed() */
 
@@ -460,14 +424,11 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **handles, gint num_handles,
 
     /* create the tree model */
 
-    ctk_window->tree_store =
-        gtk_tree_store_new(CTK_WINDOW_NUM_COLUMNS,
-                           G_TYPE_STRING,   /* Label */
-                           G_TYPE_POINTER,  /* Main widget */
-                           G_TYPE_POINTER,  /* Help widget */
-                           G_TYPE_POINTER,  /* Config file attr func */
-                           G_TYPE_POINTER,  /* Load widget func */
-                           G_TYPE_POINTER); /* Unload widget func */
+    ctk_window->tree_store = gtk_tree_store_new(CTK_WINDOW_NUM_COLUMNS,
+                                                G_TYPE_STRING,
+                                                G_TYPE_POINTER,
+                                                G_TYPE_POINTER,
+                                                G_TYPE_POINTER);
     model = GTK_TREE_MODEL(ctk_window->tree_store);
 
     /* create the tree view */
@@ -552,8 +513,8 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **handles, gint num_handles,
                                          ctk_event);
         if (child) {
             help = ctk_color_correction_create_help(tag_table);
-            add_page(child, help, ctk_window, &iter, NULL,
-                     "X Server Color Correction", NULL, NULL, NULL);
+            add_page(child, help, ctk_window, &iter,
+                     "X Server Color Correction", NULL);
         }
 
         /* xvideo settings  */
@@ -561,17 +522,8 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **handles, gint num_handles,
         child = ctk_xvideo_new(handles[i], ctk_config);
         if (child) {
             help = ctk_xvideo_create_help(tag_table, CTK_XVIDEO(child));
-            add_page(child, help, ctk_window, &iter, NULL,
-                     "X Server XVideo Settings", NULL, NULL, NULL);
-        }
-
-        /* randr settings */
-
-        child = ctk_randr_new(handles[i], ctk_config, ctk_event);
-        if (child) {
-            help = ctk_randr_create_help(tag_table, CTK_RANDR(child));
-            add_page(child, help, ctk_window, &iter, NULL,
-                     "Rotation Settings", NULL, NULL, NULL);
+            add_page(child, help, ctk_window, &iter,
+                     "X Server XVideo Settings", NULL);
         }
 
         /* cursor shadow */
@@ -580,8 +532,7 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **handles, gint num_handles,
         if (child) {
             help = ctk_cursor_shadow_create_help(tag_table,
                                                  CTK_CURSOR_SHADOW(child));
-            add_page(child, help, ctk_window, &iter, NULL, "Cursor Shadow",
-                     NULL, NULL, NULL);
+            add_page(child, help, ctk_window, &iter, "Cursor Shadow", NULL);
         }
 
         /* opengl settings */
@@ -589,58 +540,34 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **handles, gint num_handles,
         child = ctk_opengl_new(handles[i], ctk_config, ctk_event);
         if (child) {
             help = ctk_opengl_create_help(tag_table, CTK_OPENGL(child));
-            add_page(child, help, ctk_window, &iter, NULL, "OpenGL Settings",
-                     NULL, NULL, NULL);
+            add_page(child, help, ctk_window, &iter, "OpenGL Settings", NULL);
         }
 
-
-        /* GLX Information */
-
-        child = ctk_glx_new(handles[i], ctk_config, ctk_event);
-        if (child) {
-            help = ctk_glx_create_help(tag_table, CTK_GLX(child));
-            add_page(child, help, ctk_window, &iter, NULL,
-                     "OpenGL/GLX Information", NULL, ctk_glx_probe_info, NULL);
-        }
-
-
         /* multisample settings */
 
         child = ctk_multisample_new(handles[i], ctk_config, ctk_event);
         if (child) {
             help = ctk_multisample_create_help(tag_table,
                                                CTK_MULTISAMPLE(child));
-            add_page(child, help, ctk_window, &iter, NULL,
-                     "Antialiasing Settings", NULL, NULL, NULL);
+            add_page(child, help, ctk_window, &iter,
+                     "Antialiasing Settings", NULL);
         }
 
         /* thermal information */
 
         child = ctk_thermal_new(handles[i], ctk_config);
         if (child) {
-            help = ctk_thermal_create_help(tag_table, CTK_THERMAL(child));
-            add_page(child, help, ctk_window, &iter, NULL, "Thermal Monitor",
-                     NULL, ctk_thermal_start_timer, ctk_thermal_stop_timer);
+            help = ctk_thermal_create_help(tag_table);
+            add_page(child, help, ctk_window, &iter, "Thermal Monitor", NULL);
         }
         
         /* gvo (Graphics To Video Out) */
         
-        child = ctk_gvo_new(handles[i], GTK_WIDGET(ctk_window),
-                            ctk_config, ctk_event);
+        child = ctk_gvo_new(handles[i], ctk_config);
         if (child) {
             help = ctk_gvo_create_help(tag_table);
-            add_page(child, help, ctk_window, &iter, NULL,
-                     "Graphics to Video Out", NULL,
-                     ctk_gvo_select, ctk_gvo_unselect);
-        }
-
-        /* clocks (GPU overclocking) */
-
-        child = ctk_clocks_new(handles[i], ctk_config, ctk_event);
-        if (child) {
-            help = ctk_clocks_create_help(tag_table, CTK_CLOCKS(child));
-            add_page(child, help, ctk_window, &iter, NULL, "Clock Frequencies",
-                     NULL, ctk_clocks_select, NULL);
+            add_page(child, help, ctk_window, &iter,
+                     "Graphics to Video Out", NULL);
         }
 
         /* display devices */
@@ -667,10 +594,8 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **handles, gint num_handles,
         if (!widget) continue;
 
         add_page(widget, ctk_framelock_create_help(tag_table),
-                 ctk_window, NULL, NULL, "FrameLock",
-                 ctk_framelock_config_file_attributes,
-                 ctk_framelock_select,
-                 ctk_framelock_unselect);
+                 ctk_window, NULL, "FrameLock",
+                 ctk_framelock_config_file_attributes);
         break;
     }
 
@@ -678,8 +603,7 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **handles, gint num_handles,
 
     add_page(GTK_WIDGET(ctk_window->ctk_config),
              ctk_config_create_help(tag_table),
-             ctk_window, NULL, NULL, "nvidia-settings Configuration",
-             NULL, NULL, NULL);
+             ctk_window, NULL, "nvidia-settings Configuration", NULL);
 
     /*
      * we're done with the current data in the parsed attribute list,
@@ -715,49 +639,30 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **handles, gint num_handles,
 
 /*
  * add_page() - add a new page to ctk_window's tree_store, using iter
- * as a parent; the new child iter is written in pchild_iter, if
- * provided.
+ * as a parent.
  */
 
 static void add_page(GtkWidget *widget, GtkTextBuffer *help,
                      CtkWindow *ctk_window, GtkTreeIter *iter,
-                     GtkTreeIter *child_iter,
-                     const gchar *label, config_file_attributes_func_t func,
-                     select_widget_func_t select_func,
-                     unselect_widget_func_t unselect_func)                     
+                     const gchar *label, config_file_attributes_func_t func)
 {
-    GtkTreeIter tmp_child_iter;
+    GtkTreeIter child_iter;
 
     if (!widget)
         return;
 
-    if (!child_iter) child_iter = &tmp_child_iter;
-
-    /*
-     * add another reference to the widget, so that it doesn't get
-     * destroyed the next time it gets hidden (removed from the page
-     * viewer).
-     */
-    
     gtk_object_ref(GTK_OBJECT(widget));
-    
-    gtk_tree_store_append(ctk_window->tree_store, child_iter, iter);
-    
-    gtk_tree_store_set(ctk_window->tree_store, child_iter,
+    gtk_tree_store_append(ctk_window->tree_store, &child_iter, iter);
+    gtk_tree_store_set(ctk_window->tree_store, &child_iter,
                        CTK_WINDOW_LABEL_COLUMN, label, -1);
-    gtk_tree_store_set(ctk_window->tree_store, child_iter,
+    gtk_tree_store_set(ctk_window->tree_store, &child_iter,
                        CTK_WINDOW_WIDGET_COLUMN, widget, -1);
-    gtk_tree_store_set(ctk_window->tree_store, child_iter,
+    gtk_tree_store_set(ctk_window->tree_store, &child_iter,
                        CTK_WINDOW_HELP_COLUMN, help, -1);
-    gtk_tree_store_set(ctk_window->tree_store, child_iter,
+    gtk_tree_store_set(ctk_window->tree_store, &child_iter,
                        CTK_WINDOW_CONFIG_FILE_ATTRIBUTES_FUNC_COLUMN,
                        func, -1);
-    gtk_tree_store_set(ctk_window->tree_store, child_iter,
-                       CTK_WINDOW_SELECT_WIDGET_FUNC_COLUMN,
-                       select_func, -1);
-    gtk_tree_store_set(ctk_window->tree_store, child_iter,
-                       CTK_WINDOW_UNSELECT_WIDGET_FUNC_COLUMN,
-                       unselect_func, -1);
+
 } /* add_page() */
 
 
@@ -888,7 +793,7 @@ static void add_display_devices(GtkWidget *widget, GtkTextBuffer *help,
                                 CtkEvent *ctk_event,
                                 GtkTextTagTable *tag_table)
 {
-    GtkTreeIter child_iter;
+    GtkTreeIter child_iter, grandchild_iter;
     ReturnStatus ret;
     int i, enabled, n, mask;
     char *name;
@@ -917,8 +822,25 @@ static void add_display_devices(GtkWidget *widget, GtkTextBuffer *help,
         name = "Display Devices";
     }
     
-    add_page(widget, help, ctk_window, iter, &child_iter, name,
-             NULL, NULL, NULL);
+    /*
+     * add another reference to the widget, so that it doesn't get
+     * destroyed the next time it gets hidden (removed from the page
+     * viewer).
+     */
+
+    gtk_object_ref(GTK_OBJECT(widget));
+    
+    gtk_tree_store_append(ctk_window->tree_store, &child_iter, iter);
+    
+    gtk_tree_store_set(ctk_window->tree_store, &child_iter,
+                       CTK_WINDOW_LABEL_COLUMN, name, -1);
+    gtk_tree_store_set(ctk_window->tree_store, &child_iter,
+                       CTK_WINDOW_WIDGET_COLUMN, widget, -1);
+    gtk_tree_store_set(ctk_window->tree_store, &child_iter,
+                       CTK_WINDOW_HELP_COLUMN, help, -1);
+    gtk_tree_store_set(ctk_window->tree_store, &child_iter,
+                       CTK_WINDOW_CONFIG_FILE_ATTRIBUTES_FUNC_COLUMN,
+                       NULL, -1);
 
     /*
      * create pages for each of the display devices driven by this X
@@ -966,8 +888,23 @@ static void add_display_devices(GtkWidget *widget, GtkTextBuffer *help,
             continue;
         }
 
-        add_page(widget, help, ctk_window, &child_iter,
-                 NULL, name, NULL, NULL, NULL);
+        gtk_object_ref(GTK_OBJECT(widget));
+        
+        gtk_tree_store_append(ctk_window->tree_store, &grandchild_iter,
+                              &child_iter);
+    
+        gtk_tree_store_set(ctk_window->tree_store, &grandchild_iter,
+                           CTK_WINDOW_LABEL_COLUMN, name, -1);
+        
+        gtk_tree_store_set(ctk_window->tree_store, &grandchild_iter,
+                           CTK_WINDOW_WIDGET_COLUMN, widget, -1);
+    
+        gtk_tree_store_set(ctk_window->tree_store, &grandchild_iter,
+                           CTK_WINDOW_HELP_COLUMN, help, -1);
+    
+        gtk_tree_store_set(ctk_window->tree_store, &grandchild_iter,
+                           CTK_WINDOW_CONFIG_FILE_ATTRIBUTES_FUNC_COLUMN,
+                           NULL, -1);
     }
 } /* add_display_devices() */
 
