@@ -83,27 +83,9 @@ NvCtrlAttributeHandle *NvCtrlAttributeInit(Display *dpy, int screen,
      */
 
     if (subsystems & NV_CTRL_ATTRIBUTES_XVIDEO_SUBSYSTEM) {
-        h->xv = NvCtrlInitXvAttributes(h);
+        NvCtrlInitXvOverlayAttributes(h);
     }
-
-    /*
-     * initialize the GLX extension and attributes; it is OK if
-     * this fails
-     */
-
-    if (subsystems & NV_CTRL_ATTRIBUTES_GLX_SUBSYSTEM) {
-        h->glx = NvCtrlInitGlxAttributes(h);
-    }
-
-    /*
-     * initialize the XRandR extension and attributes; it is OK if
-     * this fails
-     */
-
-    if (subsystems & NV_CTRL_ATTRIBUTES_XRANDR_SUBSYSTEM) {
-        h->xrandr = NvCtrlInitXrandrAttributes(h);
-    }
-  
+    
     return (NvCtrlAttributeHandle *) h;
 
  failed:
@@ -227,20 +209,6 @@ int NvCtrlGetEventBase(NvCtrlAttributeHandle *handle)
 } /* NvCtrlGetEventBase() */
 
 
-int NvCtrlGetXrandrEventBase(NvCtrlAttributeHandle *handle)
-{
-    NvCtrlAttributePrivateHandle *h;
-
-    if (!handle) return 0;
-
-    h = (NvCtrlAttributePrivateHandle *) handle;
-
-    if (!h->xrandr) return 0;
-    return (h->xrandr->event_base);
-    
-} /* NvCtrlGetXrandrEventBase() */
-
-
 ReturnStatus NvCtrlGetAttribute(NvCtrlAttributeHandle *handle,
                                 int attr, int *val)
 {
@@ -259,15 +227,6 @@ ReturnStatus NvCtrlSetAttribute(NvCtrlAttributeHandle *handle,
 } /* NvCtrlSetAttribute() */
 
 
-ReturnStatus NvCtrlGetVoidAttribute(NvCtrlAttributeHandle *handle,
-                                    int attr, void **ptr)
-{
-    if (!handle) return NvCtrlBadArgument;
-    return NvCtrlGetVoidDisplayAttribute(handle, 0, attr, ptr);
-    
-} /* NvCtrlGetVoidAttribute() */
-
-
 ReturnStatus NvCtrlGetValidAttributeValues(NvCtrlAttributeHandle *handle,
                                            int attr,
                                            NVCTRLAttributeValidValuesRec *val)
@@ -303,11 +262,11 @@ NvCtrlGetDisplayAttribute(NvCtrlAttributeHandle *handle,
           case NV_CTRL_ATTR_EXT_VM_PRESENT:
             *val = (h->vm) ? True : False; break;
           case NV_CTRL_ATTR_EXT_XV_OVERLAY_PRESENT:
-            *val = (h->xv && h->xv->overlay) ? True : False; break;
+            *val = (h->xv_overlay) ? True : False; break;
           case NV_CTRL_ATTR_EXT_XV_TEXTURE_PRESENT:
-            *val = (h->xv && h->xv->texture) ? True : False; break;
+            *val = (h->xv_texture) ? True : False; break;
           case NV_CTRL_ATTR_EXT_XV_BLITTER_PRESENT:
-            *val = (h->xv && h->xv->blitter) ? True : False; break;
+            *val = (h->xv_blitter) ? True : False; break;
           default:
             return NvCtrlNoAttribute;
         }
@@ -324,14 +283,6 @@ NvCtrlGetDisplayAttribute(NvCtrlAttributeHandle *handle,
         
         return NvCtrlXvGetAttribute(h, attr, val);
     }
-
-    if ((attr >= NV_CTRL_ATTR_XRANDR_BASE) &&
-        (attr <= NV_CTRL_ATTR_XRANDR_LAST_ATTRIBUTE)) {
-        
-        return NvCtrlXrandrGetAttribute(h, attr, val);
-    }
-
-
     return NvCtrlNoAttribute;
     
 } /* NvCtrlGetDisplayAttribute() */
@@ -356,36 +307,11 @@ NvCtrlSetDisplayAttribute(NvCtrlAttributeHandle *handle,
         return NvCtrlXvSetAttribute(h, attr, val);
     }
     
-    if ((attr >= NV_CTRL_ATTR_XRANDR_BASE) &&
-        (attr <= NV_CTRL_ATTR_XRANDR_LAST_ATTRIBUTE)) {
-        
-        return NvCtrlXrandrSetAttribute(h, attr, val);
-    }
-
     return NvCtrlNoAttribute;
 
 } /* NvCtrlSetDisplayAttribute() */
 
 
-ReturnStatus
-NvCtrlGetVoidDisplayAttribute(NvCtrlAttributeHandle *handle,
-                              unsigned int display_mask, int attr, void **ptr)
-{
-    NvCtrlAttributePrivateHandle *h;
-
-    h = (NvCtrlAttributePrivateHandle *) handle;
-
-    if ( attr >= NV_CTRL_ATTR_GLX_BASE &&
-         attr >= NV_CTRL_ATTR_GLX_LAST_ATTRIBUTE ) {
-        if ( !(h->glx) ) return NvCtrlMissingExtension;
-        return NvCtrlGlxGetVoidAttribute(h, display_mask, attr, ptr);
-    }
-
-    return NvCtrlNoAttribute;
-
-} /* NvCtrlGetVoidDisplayAttribute() */
-
-
 ReturnStatus
 NvCtrlGetValidDisplayAttributeValues(NvCtrlAttributeHandle *handle,
                                      unsigned int display_mask, int attr,
@@ -421,17 +347,11 @@ NvCtrlGetStringDisplayAttribute(NvCtrlAttributeHandle *handle,
 
     h = (NvCtrlAttributePrivateHandle *) handle;
 
-    if ((attr >= 0) && (attr <= NV_CTRL_STRING_LAST_ATTRIBUTE)) {
+    if ((attr >= 0) && (attr <= NV_CTRL_LAST_ATTRIBUTE)) {
         if (!h->nv) return NvCtrlMissingExtension;
         return NvCtrlNvControlGetStringAttribute(h, display_mask, attr, ptr);
     }
 
-    if ((attr >= NV_CTRL_STRING_GLX_BASE) &&
-        (attr <= NV_CTRL_STRING_GLX_LAST_ATTRIBUTE)) {
-        if (!h->glx) return NvCtrlMissingExtension;
-        return NvCtrlGlxGetStringAttribute(h, display_mask, attr, ptr);
-    }
-
     return NvCtrlNoAttribute;
 
 } /* NvCtrlGetStringDisplayAttribute() */
@@ -476,15 +396,6 @@ void NvCtrlAttributeClose(NvCtrlAttributeHandle *handle)
      * subsystem
      */
 
-    if ( h->glx ) {
-        NvCtrlGlxAttributesClose(h);   
-    }
-    if ( h->xrandr ) {
-        NvCtrlXrandrAttributesClose(h);   
-    }
-    if ( h->xv ) {
-        NvCtrlXvAttributesClose(h);
-    }
-
     free(h);
+
 } /* NvCtrlAttributeClose() */
